summaryrefslogtreecommitdiffstats
path: root/Doc/includes/sqlite3/execute_1.py
diff options
context:
space:
mode:
Diffstat (limited to 'Doc/includes/sqlite3/execute_1.py')
-rw-r--r--Doc/includes/sqlite3/execute_1.py21
1 files changed, 13 insertions, 8 deletions
diff --git a/Doc/includes/sqlite3/execute_1.py b/Doc/includes/sqlite3/execute_1.py
index 3466b12..42aad4d 100644
--- a/Doc/includes/sqlite3/execute_1.py
+++ b/Doc/includes/sqlite3/execute_1.py
@@ -2,17 +2,22 @@ import sqlite3
con = sqlite3.connect(":memory:")
cur = con.cursor()
-cur.execute("create table people (name_last, age)")
-
-who = "Yeltsin"
-age = 72
+cur.execute("create table lang (lang_name, lang_age)")
# This is the qmark style:
-cur.execute("insert into people values (?, ?)", (who, age))
+cur.execute("insert into lang values (?, ?)", ("C", 49))
-# And this is the named style:
-cur.execute("select * from people where name_last=:who and age=:age", {"who": who, "age": age})
+# The qmark style used with executemany():
+lang_list = [
+ ("Fortran", 64),
+ ("Python", 30),
+ ("Go", 11),
+]
+cur.executemany("insert into lang values (?, ?)", lang_list)
-print(cur.fetchone())
+# And this is the named style:
+cur.execute("select * from lang where lang_name=:name and lang_age=:age",
+ {"name": "C", "age": 49})
+print(cur.fetchall())
con.close()